import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../AutoScalingClient";
import { DeleteLifecycleHookAnswer, DeleteLifecycleHookType } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DeleteLifecycleHookCommand}.
 */
export interface DeleteLifecycleHookCommandInput extends DeleteLifecycleHookType {
}
/**
 * @public
 *
 * The output of {@link DeleteLifecycleHookCommand}.
 */
export interface DeleteLifecycleHookCommandOutput extends DeleteLifecycleHookAnswer, __MetadataBearer {
}
declare const DeleteLifecycleHookCommand_base: {
    new (input: DeleteLifecycleHookCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteLifecycleHookCommandInput, DeleteLifecycleHookCommandOutput, AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: DeleteLifecycleHookCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteLifecycleHookCommandInput, DeleteLifecycleHookCommandOutput, AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Deletes the specified lifecycle hook.</p>
 *          <p>If there are any outstanding lifecycle actions, they are completed first
 *                 (<code>ABANDON</code> for launching instances, <code>CONTINUE</code> for terminating
 *             instances).</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { AutoScalingClient, DeleteLifecycleHookCommand } from "@aws-sdk/client-auto-scaling"; // ES Modules import
 * // const { AutoScalingClient, DeleteLifecycleHookCommand } = require("@aws-sdk/client-auto-scaling"); // CommonJS import
 * const client = new AutoScalingClient(config);
 * const input = { // DeleteLifecycleHookType
 *   LifecycleHookName: "STRING_VALUE", // required
 *   AutoScalingGroupName: "STRING_VALUE", // required
 * };
 * const command = new DeleteLifecycleHookCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param DeleteLifecycleHookCommandInput - {@link DeleteLifecycleHookCommandInput}
 * @returns {@link DeleteLifecycleHookCommandOutput}
 * @see {@link DeleteLifecycleHookCommandInput} for command's `input` shape.
 * @see {@link DeleteLifecycleHookCommandOutput} for command's `response` shape.
 * @see {@link AutoScalingClientResolvedConfig | config} for AutoScalingClient's `config` shape.
 *
 * @throws {@link ResourceContentionFault} (server fault)
 *  <p>You already have a pending update to an Amazon EC2 Auto Scaling resource (for example, an Auto Scaling group,
 *             instance, or load balancer).</p>
 *
 * @throws {@link AutoScalingServiceException}
 * <p>Base exception class for all service exceptions from AutoScaling service.</p>
 *
 * @public
 * @example To delete a lifecycle hook
 * ```javascript
 * // This example deletes the specified lifecycle hook.
 * const input = {
 *   "AutoScalingGroupName": "my-auto-scaling-group",
 *   "LifecycleHookName": "my-lifecycle-hook"
 * };
 * const command = new DeleteLifecycleHookCommand(input);
 * await client.send(command);
 * // example id: autoscaling-delete-lifecycle-hook-1
 * ```
 *
 */
export declare class DeleteLifecycleHookCommand extends DeleteLifecycleHookCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DeleteLifecycleHookType;
            output: {};
        };
        sdk: {
            input: DeleteLifecycleHookCommandInput;
            output: DeleteLifecycleHookCommandOutput;
        };
    };
}
